.. rez-pip documentation master file, created by
   sphinx-quickstart on Sat May 13 17:23:33 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

rez-pip
=======

rez-pip is a rez_ command-line plugin that you can use to make package from the `Python Package Index`_ and other indexes available to your rez package ecosystem.

.. _rez: https://github.com/AcademySoftwareFoundation/rez
.. _Python Package Index: https://pypi.org

.. toctree::
   :maxdepth: 1

   faq.rst
